package com.zehong.system.service.impl;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.zehong.common.utils.GovernmentDataCopyUtil;
import com.zehong.common.utils.GovernmentDataUtil;
import com.zehong.system.domain.FProBehInforBrowse;
import com.zehong.system.domain.TInsTaskInfor;
import com.zehong.system.domain.TProAppInforBrowse;
import com.zehong.system.domain.vo.ProAppInforBrowseVo;
import com.zehong.system.domain.vo.ProBehInfoBrowseVo;
import com.zehong.system.domain.vo.TInsTaskInforVo;
import com.zehong.system.mapper.FProBehInforBrowseMapper;
import com.zehong.system.mapper.TInsTaskInforMapper;
import com.zehong.system.mapper.TProAppInforBrowseMapper;
import com.zehong.system.service.GovernmentSupervisionInfoService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * @author geng
 * 政府监管平台信息
 */
@Service
public class GovernmentSupervisionInfoServiceImpl implements GovernmentSupervisionInfoService {

    private static final Logger log = LoggerFactory.getLogger(GovernmentSupervisionInfoServiceImpl.class);

    @Resource
    private GovernmentDataUtil governmentDataUtil;

    @Resource
    private TProAppInforBrowseMapper tProAppInforBrowseMapper;

    @Resource
    private FProBehInforBrowseMapper fProBehInforBrowseMapper;

    @Resource
    private TInsTaskInforMapper tInsTaskInforMapper;

    /**
     * 获取行业专家档案
     * @param map 入参
     * @return
     * @throws Exception
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public JSONObject getProfessorInfo(Map<String, Object> map) throws Exception {
        JSONObject json = governmentDataUtil.getInfo("professor/application/information","READ",map);
        log.info("获取行业专家档案结果=========" + json.toString());
        //结果入库
        if(null != json && "0".equals(json.getString("resultCode")) && null != json.getJSONArray("data")){
            JSONArray data = json.getJSONArray("data");
            List<TProAppInforBrowse> proAppInforBrowseList = new ArrayList<>();
            for(int i = 0; i < data.size(); i++){
                ProAppInforBrowseVo proAppInforBrowseVo = JSONObject.toJavaObject(data.getJSONObject(i), ProAppInforBrowseVo.class);
                TProAppInforBrowse tProAppInforBrowse = new TProAppInforBrowse();
                GovernmentDataCopyUtil.copyToLocalData(proAppInforBrowseVo,tProAppInforBrowse);
                proAppInforBrowseList.add(tProAppInforBrowse);
            }
            tProAppInforBrowseMapper.batchInsertTProAppInforBrowse(proAppInforBrowseList);
        }
        return json;
    }

    /**
     * 获取专家行为档案
     * @param map 入参
     * @return
     * @throws Exception
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public JSONObject getBehaviour(Map<String, Object> map) throws Exception {
        JSONObject json = governmentDataUtil.getInfo("professor/behaviour/information","READ",map);
        log.info("获取专家行为档案结果=========" + json.toString());
        if(null != json && "0".equals(json.getString("resultCode")) && null != json.getJSONArray("data")){
            JSONArray data = json.getJSONArray("data");
            List<FProBehInforBrowse> proBehInforBrowseList = new ArrayList<>();
            for(int i = 0; i < data.size(); i++){
                ProBehInfoBrowseVo proBehInfoBrowseVo = JSONObject.toJavaObject(data.getJSONObject(i), ProBehInfoBrowseVo.class);
                FProBehInforBrowse proBehInforBrowse = new FProBehInforBrowse();
                GovernmentDataCopyUtil.copyToLocalData(proBehInfoBrowseVo,proBehInforBrowse);
                proBehInforBrowseList.add(proBehInforBrowse);
            }
            fProBehInforBrowseMapper.batchInsertFProBehInforBrowse(proBehInforBrowseList);
        }
        return json;
    }

    /**
     * 获取检查任务
     * @param map 入参
     * @return
     * @throws Exception
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public JSONObject getTask(Map<String, Object> map) throws Exception {
        JSONObject json = governmentDataUtil.getInfo("inspection/task/information","READ",map);
        log.info("获取检查任务结果=========" + json.toString());
        if(null != json && "0".equals(json.getString("resultCode")) && null != json.getJSONArray("data")){
            JSONArray data = json.getJSONArray("data");
            List<TInsTaskInfor> taskInforList = new ArrayList<>();
            for(int i = 0; i < data.size(); i++){
                TInsTaskInforVo tInsTaskInforVo = JSONObject.toJavaObject(data.getJSONObject(i), TInsTaskInforVo.class);
                TInsTaskInfor tInsTaskInfor = new TInsTaskInfor();
                GovernmentDataCopyUtil.copyToLocalData(tInsTaskInforVo,tInsTaskInfor);
                taskInforList.add(tInsTaskInfor);
            }
            tInsTaskInforMapper.batchInsertTInsTaskInfo(taskInforList);
        }
        return null;
    }


}
